@@ -143,7 +143,8 @@ assess_missing_data_tsne <- function(vcfR,
     #execute PCA using this genlight
     #retain number of PC axes equivalent to the number of populations being discriminated + 2
     pca<-adegenet::glPca(gen,
-                         nf=length(levels(as.factor(popmap$pop)))+2)
+                         nf=length(levels(as.factor(popmap$pop)))+2,
+                         useC = FALSE)
 
     #pull pca scores out of df
     pca.scores<-as.data.frame(pca$scores)
@@ -260,7 +261,8 @@ assess_missing_data_tsne <- function(vcfR,
       #execute PCA using this genlight
       #retain number of PC axes equivalent to the number of populations being discriminated + 2
       pca<-adegenet::glPca(gen,
-                           nf=length(levels(as.factor(popmap$pop)))+2)
+                           nf=length(levels(as.factor(popmap$pop)))+2,
+                           useC = FALSE)
 
       #pull pca scores out of df
       pca.scores<-as.data.frame(pca$scores)
@@ -379,7 +381,8 @@ assess_missing_data_tsne <- function(vcfR,
       #execute PCA using this genlight
       #retain number of PC axes equivalent to the number of populations being discriminated + 2
       pca<-adegenet::glPca(gen,
-                           nf=length(levels(as.factor(popmap$pop)))+2)
+                           nf=length(levels(as.factor(popmap$pop)))+2,
+                           useC = FALSE)
 
       #pull pca scores out of df
       pca.scores<-as.data.frame(pca$scores)
@@ -473,7 +476,8 @@ assess_missing_data_tsne <- function(vcfR,
         #execute PCA using this genlight
         #retain number of PC axes equivalent to the number of populations being discriminated + 2
         pca<-adegenet::glPca(gen,
-                             nf=length(levels(as.factor(popmap$pop)))+2)
+                             nf=length(levels(as.factor(popmap$pop)))+2,
+                             useC = FALSE)
 
         #pull pca scores out of df
         pca.scores<-as.data.frame(pca$scores)
